.. File auto-generated by ``generate_summary_table.py``

.. tabularcolumns:: |L|L|L|l|l|

.. list-table:: Reader/Writer Summary Table (Subset of Readers)
    :header-rows: 1

    * - **Input Source**
      - **Input Filename Pattern**
      - **Output Type**
      - **Reader Name**
      - **Writer Name**
    * - **Suomi-NPP VIIRS Sensor Data Records**
      - SVI01_npp_*.h5
        GITCO_npp_*.h5
      - 8-bit single band GeoTIFF
      - viirs_sdr
      - geotiff
    * - "
      - "
      - AWIPS NetCDF
      - viirs_sdr
      - awips_tiled
    * - "
      - "
      - HDF5
      - viirs_sdr
      - hdf5
    * - "
      - "
      - Binary
      - viirs_sdr
      - binary
    * - "
      - "
      - 24-bit true and false color GeoTIFF
      - viirs_sdr
      - geotiff
    * - **Aqua and Terra MODIS Level 1b (IMAPP or NASA archive files)**
      - MOD021KM*.hdf
        MOD03*.hdf

        or

        t1.*1000m.hdf
        t1.*.geo.hdf
      - 8 bit single band GeoTIFF
      - modis_l1b
      - geotiff
    * - "
      - "
      - AWIPS NetCDF
      - modis_l1b
      - awips_tiled
    * - "
      - "
      - HDF5
      - modis_l1b
      - hdf5
    * - "
      - "
      - Binary
      - modis_l1b
      - binary
    * - "
      - "
      - 24-bit true and false color GeoTIFF
      - modis_l1b
      - geotiff
    * - **NOAA-18, NOAA-19,Metop-A,-B,-C AVHRR AAPP Level 1b**
      - hrpt_noaa18_*.l1b
      - 8 bit single band GeoTIFF
      - avhrr_l1b
      - geotiff
    * - "
      - "
      - AWIPS NetCDF
      - avhrr_l1b
      - awips_tiled
    * - "
      - "
      - HDF5
      - avhrr_l1b
      - hdf5
    * - "
      - "
      - Binary
      - avhrr_l1b
      - binary
    * - **GCOM-W1 ASMR2 L1B**
      - GW1AM2\*L1DLBTBR\*.h5
      - 8 bit single band GeoTIFF
      - amsr2_l1b
      - geotiff
    * - "
      - "
      - AWIPS NetCDF
      - amsr2_l1b
      - awips_tiled
    * - "
      - "
      - HDF5
      - amsr2_l1b
      - hdf5
    * - "
      - "
      - Binary
      - amsr2_l1b
      - binary
    * - **FY3-D MERSI2 L1B**
      - tf\*.FY3D\-X_MERSI_*_L1B.HDF
      - 8 bit single band GeoTIFF, 24-bit true and false color GeoTIFF
      - mersi2_l1b
      - geotiff
    * - "
      - "
      - HDF5
      - mersi2_l1b
      - hdf5
    * - "
      - "
      - Binary
      - mersi2_l1b
      - binary
    * - **CLAVR-x Cloud Retrievals**
      - clavrx*.hdf
      - 8 bit single band GeoTIFF
      - clavrx
      - geotiff
    * - "
      - "
      - AWIPS NetCDF
      - clavrx
      - awips_tiled
    * - "
      - "
      - HDF5
      - clavrx
      - hdf5
    * - "
      - "
      - Binary
      - clavrx
      - binary
    * - **ACSPO Sea Surface Temperatures**
      - \*-STAR-L2P_GHRSST-SSTskin-\*.nc
      - 8 bit single band GeoTIFF
      - acspo
      - geotiff
    * - "
      - "
      - AWIPS NetCDF
      - acspo
      - awips_tiled
    * - "
      - "
      - HDF5
      - acspo
      - hdf5
    * - "
      - "
      - Binary
      - acspo
      - binary
